package kieker.webgui.beans;

import java.io.File;
import java.util.ArrayList;
import java.util.List;

import javax.faces.bean.ApplicationScoped;
import javax.faces.bean.ManagedBean;
import javax.faces.context.FacesContext;

import kieker.analysis.AnalysisController;
import kieker.analysis.model.analysisMetaModel.MIProject;
import kieker.analysis.model.analysisMetaModel.impl.MAnalysisMetaModelFactory;

import org.primefaces.model.DefaultTreeNode;
import org.primefaces.model.TreeNode;

/**
 * This bean can be used to handle all available projects within the program.
 *
 * @author Nils Christian Ehmke
 */
@ManagedBean
@ApplicationScoped
public class AvailableProjectsBean {

    private final String PROJECT_DIR = "projects";
    private final List<MIProject> projects;
    private final MAnalysisMetaModelFactory factory;

    public AvailableProjectsBean() {
        projects = new ArrayList<MIProject>();
        factory = new MAnalysisMetaModelFactory();
    }

    public synchronized boolean addProject(final String projectName) {
        final MIProject project = factory.createProject();
        project.setName(projectName);

        try {
            File dir = new File(PROJECT_DIR + "/" + projectName);
            if (!dir.exists()) {
                dir.mkdir();
            } else {
            	/* The project exists already. */
            	return false;
            }
            File f = new File(dir + "/" + projectName + ".xml");
            new AnalysisController(project).saveToFile(f, projectName);
        } catch (Exception ex) {
            System.out.println(ex);
        }

        FacesContext context = FacesContext.getCurrentInstance();
        SelectedProjectBean bean = (SelectedProjectBean) context.getApplication().evaluateExpressionGet(context, "#{selectedProjectBean}", SelectedProjectBean.class);
        if (bean.getMainProject() == null) {
            bean.setMainProject(project);
        }

        return projects.add(project);
    }

    @SuppressWarnings(value = { "unused" })
    public synchronized TreeNode getProjectsRoot() {
        TreeNode root = new DefaultTreeNode("Root", null);

        for (final MIProject project : projects) {
            final TreeNode projectNode = new DefaultTreeNode("project", project, root);
            final TreeNode dependenciesNode = new DefaultTreeNode("dependencies", "Dependencies", projectNode);
            final TreeNode usedPluginsNode = new DefaultTreeNode("usedPlugins", "Used Plugins", projectNode);
        }

        return root;
    }
}
